==> aria2_1.10.0.orig.tar.gz: aria2-1.10.0/src/DHTTaskQueueImpl.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_DHT_TASK_QUEUE_IMPL_H_
#define _D_DHT_TASK_QUEUE_IMPL_H_

#include "DHTTaskQueue.h"
#include <deque>

namespace aria2 {

class DHTTaskQueueImpl:public DHTTaskQueue {
private:

  SharedHandle<DHTTask> periodicTask1_;

  SharedHandle<DHTTask> periodicTask2_;

  SharedHandle<DHTTask> immediateTask_;

  std::deque<SharedHandle<DHTTask> > periodicTaskQueue1_;

  std::deque<SharedHandle<DHTTask> > periodicTaskQueue2_;

  std::deque<SharedHandle<DHTTask> > immediateTaskQueue_;

  void executeTask(SharedHandle<DHTTask>& task, std::deque<SharedHandle<DHTTask> >& taskQueue);
public:
  DHTTaskQueueImpl();

  virtual ~DHTTaskQueueImpl();

  virtual void executeTask();

  virtual void addPeriodicTask1(const SharedHandle<DHTTask>& task);

  virtual void addPeriodicTask2(const SharedHandle<DHTTask>& task);

  virtual void addImmediateTask(const SharedHandle<DHTTask>& task);
};

} // namespace aria2

#endif // _D_DHT_TASK_QUEUE_IMPL_H_

==> aria2_1.35.0.orig.tar.gz: aria2-1.35.0/src/DHTTaskQueueImpl.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_DHT_TASK_QUEUE_IMPL_H
#define D_DHT_TASK_QUEUE_IMPL_H

#include "DHTTaskQueue.h"
#include "DHTTaskExecutor.h"

namespace aria2 {

class DHTTaskQueueImpl : public DHTTaskQueue {
private:
  DHTTaskExecutor periodicTaskQueue1_;

  DHTTaskExecutor periodicTaskQueue2_;

  DHTTaskExecutor immediateTaskQueue_;

public:
  DHTTaskQueueImpl();

  virtual ~DHTTaskQueueImpl();

  virtual void executeTask() CXX11_OVERRIDE;

  virtual void
  addPeriodicTask1(const std::shared_ptr<DHTTask>& task) CXX11_OVERRIDE;

  virtual void
  addPeriodicTask2(const std::shared_ptr<DHTTask>& task) CXX11_OVERRIDE;

  virtual void
  addImmediateTask(const std::shared_ptr<DHTTask>& task) CXX11_OVERRIDE;
};

} // namespace aria2

#endif // D_DHT_TASK_QUEUE_IMPL_H
